@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from ed_design.colors import Colors
-from ed_design.logo import logo
+from ed_design.logo import ed_logo
 
 
 
