@@ -1,11 +1,9 @@
 # -*- coding: utf-8 -*-
 import matplotlib.pyplot as plt
+import os
 #%%
 
-import os 
-dir_path = os.path.dirname(__file__)
-
-def logo(kind='print'):
+def ed_logo(kind='print'):
     """
     Load EnviDan logo for use in for example a Matplotlib figure
     
@@ -29,10 +27,13 @@ def logo(kind='print'):
 
     """
     
+    dir_path = os.path.dirname(__file__)
+
     if kind == 'print':
-        logo = plt.imread(f'{dir_path}/ed_design/_media/Envidan_Logo_Blue_TRYK_jpg.jpg')
+        logo = plt.imread(f'{dir_path}/_media/ed_logo_blue_print.jpg')
     elif kind == 'web':
-        logo = plt.imread(f'{dir_path}/ed_design/_media/Envidan_Logo_Blue_WEB.png')
+        logo = plt.imread(f'{dir_path}/_media/ed_logo_blue_web.png')
     else:
         raise NameError(f'{kind} is unknown')
-    return logo
\ No newline at end of file
+    return logo
+
